from setuptools import find_packages, setup

VERSION = "3.5.0"

setup(
    name='testit-adapter-behave',
    version=VERSION,
    description='Behave adapter for Test IT',
    long_description=open('README.md', "r").read(),
    long_description_content_type="text/markdown",
    url='https://github.com/testit-tms/adapters-python/',
    author='Integration team',
    author_email='integrations@testit.software',
    license='Apache-2.0',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    py_modules=['testit_adapter_behave'],
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=[
        'behave',
        'testit-python-commons==3.5.0',
        'attrs'],
)



from attr import attrib, attrs


# TODO: Add model to python-commons
@attrs(kw_only=True)
class Option(object):
    set_url = attrib(default=None)
    set_private_token = attrib(default=None)
    set_project_id = attrib(default=None)
    set_configuration_id = attrib(default=None)
    set_test_run_id = attrib(default=None)
    set_test_run_name = attrib(default=None)
    set_tms_proxy = attrib(default=None)
    set_adapter_mode = attrib(default=None)
    set_config_file = attrib(default=None)
    set_cert_validation = attrib(default=None)
    set_automatic_creation_test_cases = attrib(default=None)
    set_automatic_updation_links_to_test_cases = attrib(default=None)
    set_import_realtime = attrib(default=None)
